The health monitor is used to determine the health of your pool members. Health checks routinely run against each member within the pool and the result of the health check is used to determine if the member receives new connections. Each pool can only have one health monitor.

Interval: The interval between health checks. Must be greater than or equal to the timeout.

Retries: The number of allowed connection failures before marking the member as inactive. Must be a number from 1 to 10.

Retries down: The number of allowed connection failures before marking the member as error. Must be a number from 1 to 10. The default is 3.

Timeout: The time after which a health check times out. Must be a number greater than or equal to 0 and less than or equal to the interval.

HTTP method: The HTTP method used to perform the health check.

Expected status codes: The expected HTTP status codes to get from a successful health check. Must be a single number, a comma separated list of numbers, or a range (two numbers separated by a hyphen).

URL path: The target of the health check HTTP request to the member. Must be a valid URL path.